# Technical Users
### On this page
  * [Creating a Technical User](https://help.sap.com/docs/leanix/ea/technical-users#creating-a-technical-user)
  * [Managing Technical Users](https://help.sap.com/docs/leanix/ea/technical-users#managing-technical-users)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/technical-users#best-practices)


To get an API token, create a technical user. Manage technical users collaboratively with other administrators.
As an administrator, you can get an API token by creating a technical user. With an API token, you can request an access token to authenticate to SAP LeanIX services. For more information, see [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to authenticate to SAP LeanIX services.").
With technical users, you get the following benefits:
  * Integrations are no longer tied to a specific person, which allows you to avoid problems such as the person being on vacation or otherwise unavailable.
  * Users who don't have access to a workspace can still manage integrations and access SAP LeanIX APIs.
  * Technical Users can be subscribed to fact sheets for better integration building.
  * Technical Users can be subscribed to notifications with a group email address, which allows you to efficiently manage notifications in your organization.
